@@ -1,9 +1,14 @@
 #!/usr/bin/env python3
+"""
+This module fetches chunks of chemical shift data from BMRB database for given list of atoms or residues.
+It exports the chemical shift data for Histogram module. This module is not intended to call directly, but can be
+used for data mining.
+"""
 import json
 import logging
 from urllib.request import urlopen, Request
 import numpy
-from typing import Union, List
+from typing import Union, List, Optional
 
 # Set the log level to INFO
 logging.getLogger().setLevel(logging.INFO)
@@ -18,13 +23,17 @@ three_letter_code = {'I': 'ILE', 'Q': 'GLN', 'G': 'GLY', 'E': 'GLU', 'C': 'CYS',
 one_letter_code = dict([(value, key) for key, value in three_letter_code.items()])
 
 
-def _get_data_from_api(residue: str, atom: str) -> dict:
+def _get_data_from_api(residue: str,
+                       atom: str) -> dict:
     """
     Dumps the BMRB-API return for given residue and atom. Not intend to call directly
 
     :param residue: Residue name in IUPAC format
+    :type residue: str
     :param atom: Atom name in IUPAC format
+    :type atom: str
     :return: API dump
+    :rtype: dict
     """
     # logging.info('Fetching chemical shift data for {}-{}'.format(residue,atom))
     if residue == "*" and atom == "*":
@@ -37,6 +46,7 @@ def _get_data_from_api(residue: str, atom: str) -> dict:
     else:
         url = Request(_API_URL + "/search/chemical_shifts?comp_id={}&atom_id={}".format(residue, atom))
     logging.debug(_API_URL + "/search/chemical_shifts?comp_id={}&atom_id={}".format(residue, atom))
+    logging.debug(_API_URL + "/search/chemical_shifts?comp_id={}&atom_id={}".format(residue, atom))
     logging.info('Fetching chemical shift data for {}-{}'.format(residue, atom))
     url.add_header('Application', 'PyBMRB')
     r = urlopen(url)
@@ -44,24 +54,44 @@ def _get_data_from_api(residue: str, atom: str) -> dict:
     return dump
 
 
-def get_data(residue: str, atom: str, filtered: bool = True, sd_limit: float = 10, ambiguity: Union[str, int] = '*',
-             ph_min: float = None, ph_max: float = None, t_min: float = None,
-             t_max: float = None, standard_amino_acids: bool = True) -> tuple:
+def get_data(residue: str,
+             atom: str,
+             filtered: Optional[bool] = True,
+             sd_limit: Optional[float] = 10.0,
+             ambiguity: Optional[Union[str, int]] = '*',
+             ph_min: Optional[float] = None,
+             ph_max: Optional[float] = None,
+             t_min: Optional[float] = None,
+             t_max: Optional[float] = None,
+             standard_amino_acids: Optional[bool] = True) -> tuple:
     """
     Fetches the data from BMRB-API for given residue and atom and filters based of the values provided in the
     parameters
 
-    :param residue: Residue name in IPUPAC format; use '*' for any residue
-    :param atom: Atom name in IUPAC format; Wild card supported '*' for any atom
-    :param filtered: Filters values beyond (sd_limt)*(standard deviation) on both sides of the mean; default:True
-    :param sd_limit: scaling factor used to filter data based on standard deviation; default 10
-    :param ambiguity: ambiguity filter; default '*' => no filter
-    :param ph_min: PH filter (min);default None
-    :param ph_max: PH filter (max); default None
-    :param t_min: Temperature filter (min); default None
-    :param t_max: Temperature filter (max); default None
-    :param standard_amino_acids: get data only form standard amino acids and nucleic acids; default:True
-    :return: column names and data as tuple (columns,data)
+    :param residue: Residue name in IUPAC format; use \'*\' for any residue
+    :type residue: str
+    :param atom: Atom name in IUPAC format; Wild card supported; example HB*; use '*' for any atom
+    :type atom: str
+    :param filtered: Filters values beyond (sd_limit)*(standard deviation) on both sides of the mean,
+        defaults to True
+    :type filtered: bool, optional
+    :param sd_limit: scaling factor used to filter data based on standard deviation, defaults to 10.0
+    :type sd_limit: float, optional
+    :param ambiguity: filter based on chemical shift ambiguity code, defaults to * means no filter
+    :type ambiguity: str, optional
+    :param ph_min: minimum value for the filter based on PH value, defaults to None
+    :type ph_min: float, optional
+    :param ph_max: maximum value for the filter based on PH value, defaults to None
+    :type ph_max: float, optional
+    :param t_min: minimum value for the filter based on temperature value, defaults to None
+    :type t_min: float, optional
+    :param t_max: maximum value for the filter based on temperature value, defaults to None
+    :type t_max: float, optional
+    :param standard_amino_acids: get data only form standard amino acids and nucleic acids when * is used for residue,
+        defaults to True
+    :type standard_amino_acids: bool, optional
+    :return: column names and chemical shift data as tuple (columns,data)
+    :rtype: tuple
     """
 
     standard = ['ILE', 'GLN', 'GLY', 'GLU', 'CYS',
@@ -78,6 +108,18 @@ def get_data(residue: str, atom: str, filtered: bool = True, sd_limit: float = 1
     atm_index = columns.index('Atom_chem_shift.Atom_ID')
     amb_index = columns.index('Atom_chem_shift.Ambiguity_code')
     data = api_data['data']
+    for i in range(len(data)):
+        data[i][cs_index] = float(data[i][cs_index])
+        if t_min is not None or t_max is not None:
+            try:
+                data[i][temp_index] = float(data[i][temp_index])
+            except TypeError:
+                pass
+        if ph_min is not None or ph_max is not None:
+            try:
+                data[i][ph_index] = float(data[i][ph_index])
+            except TypeError:
+                pass
     if len(data):
         if standard_amino_acids:
             data = [i for i in data if i[res_index] in standard]
@@ -88,7 +130,7 @@ def get_data(residue: str, atom: str, filtered: bool = True, sd_limit: float = 1
             a_dict = {}
             for atm in atom_list:
                 a_dict[atm] = {}
-                tmp_cs = [i[cs_index] for i in data if i[atm_index] == atm]
+                tmp_cs = [float(i[cs_index]) for i in data if i[atm_index] == atm]
                 a_dict[atm]['sd'] = numpy.std(tmp_cs)
                 a_dict[atm]['avg'] = numpy.mean(tmp_cs)
                 a_dict[atm]['min_cs'] = a_dict[atm]['avg'] - (sd_limit * a_dict[atm]['sd'])
@@ -99,47 +141,72 @@ def get_data(residue: str, atom: str, filtered: bool = True, sd_limit: float = 1
             # avg = numpy.mean(cs)
             # min_cs = avg - (sd_limit * sd)
             # max_cs = avg + (sd_limit * sd)
-            data = [i for i in data if a_dict[i[atm_index]]['min_cs'] < i[cs_index] < a_dict[i[atm_index]]['max_cs']]
+            data = [i for i in data if
+                    a_dict[i[atm_index]]['min_cs'] < float(i[cs_index]) < a_dict[i[atm_index]]['max_cs']]
         if ph_min is not None:
-            data = [i for i in data if i[ph_index] is not None and i[ph_index] >= ph_min]
+            data2 = [i for i in data if i[ph_index] is not None]
+            data = [i for i in data2 if i[ph_index] is not None and i[ph_index] >= ph_min]
         if ph_max is not None:
-            data = [i for i in data if i[ph_index] is not None and i[ph_index] <= ph_max]
+            data2 = [i for i in data if i[ph_index] is not None]
+            data = [i for i in data2 if i[ph_index] is not None and i[ph_index] <= ph_max]
         if t_min is not None:
-            data = [i for i in data if i[temp_index] >= t_min]
+            data2 = [i for i in data if i[temp_index] is not None]
+            data = [i for i in data2 if i[temp_index] >= t_min]
         if t_max is not None:
-            data = [i for i in data if i[temp_index] <= t_max]
+            data2 = [i for i in data if i[temp_index] is not None]
+            data = [i for i in data2 if i[temp_index] <= t_max]
     else:
         logging.info('Data for {}-{} not found in BMRB database'.format(residue, atom))
     return columns, data
 
 
-def get_data_from_bmrb(residue: str = None, atom: str = None, list_of_atoms: Union[str, List[str]] = None,
-                       filtered: bool = True,
-                       sd_limit: float = 10, ambiguity: Union[str, int] = '*',
-                       ph_min: float = None, ph_max: float = None, t_min: float = None, t_max: float = None,
-                       standard_amino_acids: bool = True) -> tuple:
+def get_data_from_bmrb(residue: str = None,
+                       atom: str = None,
+                       list_of_atoms: Optional[Union[str, List[str]]] = None,
+                       filtered: Optional[bool] = True,
+                       sd_limit: Optional[float] = 10.0,
+                       ambiguity: Optional[Union[str, int]] = '*',
+                       ph_min: Optional[float] = None,
+                       ph_max: Optional[float] = None,
+                       t_min: Optional[float] = None,
+                       t_max: Optional[float] = None,
+                       standard_amino_acids: Optional[bool] = True) -> tuple:
     """
     Fetches the data from BMRB-API for given residue/list of residues (and/or)  atom/list of atoms and
      filters based of the values provided in the parameters
 
-    :param residue: Single residue name or list of residue names  in IUPAC format
-    :param atom: Single atom name or list of atom names in IUPAC format
-    :param list_of_atoms: list of atoms; example ['ALA-CB','CYS-N','TYR-CB']
-    :param filtered: Filters values beyond (sd_limt)*(standard deviation) on both sides of the mean; default:True
-    :param sd_limit: scaling factor used to filter data based on standard deviation; default 10
-    :param ambiguity: ambiguity filter; default '*' => no filter
-    :param ph_min: PH filter (min);default None
-    :param ph_max: PH filter (max); default None
-    :param t_min: Temperature filter (min); default None
-    :param t_max: Temperature filter (max); default None
-    :param standard_amino_acids: get data only form standard amino acids and nucleic acids; default:True
-    :return: column names and data as tuple (columns,data)
+    :param residue: Residue name in IUPAC format; use '*' for any residue
+    :type residue: str
+    :param atom: Atom name in IUPAC format; Wild card supported; example HB*; use '*' for any atom
+    :type atom: str
+    :param list_of_atoms: list of atoms; example ['ALA-CB','CYS-N','TYR-CB'], defaults to None
+    :type list_of_atoms: list, optional
+    :param filtered: Filters values beyond (sd_limit)*(standard deviation) on both sides of the mean,
+        defaults to True
+    :type filtered: bool, optional
+    :param sd_limit: scaling factor used to filter data based on standard deviation, defaults to 10.0
+    :type sd_limit: float, optional
+    :param ambiguity: filter based on chemical shift ambiguity code, defaults to '*' means no filter
+    :type ambiguity: str, optional
+    :param ph_min: minimum value for the filter based on PH value, defaults to None
+    :type ph_min: float, optional
+    :param ph_max: maximum value for the filter based on PH value, defaults to None
+    :type ph_max: float, optional
+    :param t_min: minimum value for the filter based on temperature value, defaults to None
+    :type t_min: float, optional
+    :param t_max: maximum value for the filter based on temperature value, defaults to None
+    :type t_max: float, optional
+    :param standard_amino_acids: get data only form standard amino acids and nucleic acids when '*' is used for residue,
+        defaults to True
+    :type standard_amino_acids: bool, optional
+    :return: column names and chemical shift data as tuple (columns,data)
+    :rtype: tuple
     """
 
     if residue is None and atom is None and list_of_atoms is None:
         logging.error('Please provide residue name or atom name or list of atoms as a list ')
         raise TypeError(
-            'Please provide at leaset one of the three positional arguments: residue (or) atom (or) list_of_atoms')
+            'Please provide at least one of the three positional arguments: residue (or) atom (or) list_of_atoms')
     columns = []
     out_dat = []
     if list_of_atoms is not None:
@@ -302,14 +369,18 @@ def get_data_from_bmrb(residue: str = None, atom: str = None, list_of_atoms: Uni
     return columns, out_dat
 
 
-def _list_to_dict(columns: List[str], data: list) -> dict:
+def _list_to_dict(columns: List[str],
+                  data: list) -> dict:
     """
-    Converts the outputs from get_data_from_bmrb into a dictionary. Not intend to call directly
+    Converts the outputs from get_data_from_bmrb into a dictionary. Not intended to call directly
 
     :param columns: Column headers
+    :type columns: list
     :param data: data as list of lists
+    :type data: list
     :return: chemical shift dictionary; { entry_id-entity_id-seq_id-residue-chemical_shift_list_id:
     {atom:(chemical shift, ambiguity code}}
+    :rtype: dict
     """
     # entity_index = columns.index('Atom_chem_shift.Entity_ID')
     entity_assembly_index = columns.index('Atom_chem_shift.Entity_assembly_ID')
@@ -341,26 +412,46 @@ def _list_to_dict(columns: List[str], data: list) -> dict:
     return cs_dict
 
 
-def get_2d_chemical_shifts(residue: str, atom1: str, atom2: str, filtered: bool = True, sd_limit: float = 10,
-                           ambiguity1: Union[str, int] = '*', ambiguity2: Union[str, int] = '*',
-                           ph_min: float = None, ph_max: float = None, t_min: float = None,
-                           t_max: float = None) -> tuple:
+def get_2d_chemical_shifts(residue: str,
+                           atom1: str,
+                           atom2: str,
+                           filtered: Optional[bool] = True,
+                           sd_limit: Optional[float] = 10,
+                           ambiguity1: Optional[Union[str, int]] = '*',
+                           ambiguity2: Optional[Union[str, int]] = '*',
+                           ph_min: Optional[float] = None,
+                           ph_max: Optional[float] = None,
+                           t_min: Optional[float] = None,
+                           t_max: Optional[float] = None) -> tuple:
     """
     Fetches chemical shift data for a given residue and combines the desired two atoms chemical shift value from the
     same residue as two dimensional list
 
     :param residue: residue name in IUPAC format
+    :type residue: str
     :param atom1: atom name in IUPAC format
+    :type atom1: str
     :param atom2: atom name in IUPAC format
-    :param filtered: Filters values beyond (sd_limt)*(standard deviation) on both sides of the mean; default:True
-    :param sd_limit: scaling factor used to filter data based on standard deviation; default 10
-    :param ambiguity1: ambiguity filter; default '*' (no filter)
-    :param ambiguity2: ambiguity filter; default '*'  (no filter)
-    :param ph_min: PH filter (min);default None
-    :param ph_max: PH filter (max); default None
-    :param t_min: Temperature filter (min); default None
-    :param t_max: Temperature filter (max); default None
+    :type atom2: str
+    :param filtered: Filters values beyond (sd_limit)*(standard deviation) on both sides of the mean,
+        defaults to True
+    :type filtered: bool, optional
+    :param sd_limit: scaling factor used to filter data based on standard deviation, defaults to 10.0
+    :type sd_limit: float, optional
+    :param ambiguity1: filter based on chemical shift ambiguity code for atom1, defaults to '*' means no filter
+    :type ambiguity1: str, optional
+    :param ambiguity2: filter based on chemical shift ambiguity code for atom2, defaults to '*' means no filter
+    :type ambiguity2: str, optional
+    :param ph_min: minimum value for the filter based on PH value, defaults to None
+    :type ph_min: float, optional
+    :param ph_max: maximum value for the filter based on PH value, defaults to None
+    :type ph_max: float, optional
+    :param t_min: minimum value for the filter based on temperature value, defaults to None
+    :type t_min: float, optional
+    :param t_max: maximum value for the filter based on temperature value, defaults to None
+    :type t_max: float, optional
     :return: tuple of lists (atom1_cs,atom2_cs as list)
+    :rtype: tuple
     """
 
     x = []
@@ -404,21 +495,50 @@ def get_2d_chemical_shifts(residue: str, atom1: str, atom2: str, filtered: bool
     return cs_x, cs_y
 
 
-def get_filtered_data_from_bmrb(residue: str, atom: str, filtering_rules: list,
-                                ph_min: float = None, ph_max: float = None, t_min: float = None,
-                                t_max: float = None, standard_amino_acids: bool = True) -> list:
+def get_filtered_data_from_bmrb(residue: str,
+                                atom: str,
+                                filtering_rules: Optional[list],
+                                ph_min: Optional[float] = None,
+                                ph_max: Optional[float] = None,
+                                t_min: Optional[float] = None,
+                                t_max: Optional[float] = None,
+                                h_tolerance: Optional[float] = 0.1,
+                                c_tolerance: Optional[float] = 2.0,
+                                n_tolerance: Optional[float] = 2.0,
+                                standard_amino_acids: Optional[bool] = True) -> list:
     """
-    Fetches the chemical shift data for a given residue and filters them using filtering rules
+    Fetches the chemical shift data for a given residue and filters them using chemical shift values of other atoms in
+    the same residue as a filter
 
-    :param residue: residue name in IUPAC format; example 'CYS'
-    :param atom: atom name in IUPAC format; example 'CB'
-    :param filtering_rules: list of atoms and chemical shift values as tuples; example[('CA',64.5),('H',7.8)]
-    :param ph_min: PH cs_filt (min);default None
-    :param ph_max: PH cs_filt (max); default None
-    :param t_min: Temperature cs_filt (min); default None
-    :param t_max: Temperature cs_filt (max); default None
-    :param standard_amino_acids: get data only form  standard amino acids and nucleic acids; default:True
+    :param residue: residue name in IUPAC format
+    :type residue: str
+    :param atom: atom name in IUPAC format
+    :type atom: str
+    :param filtering_rules: list of atoms and chemical shift values as
+        tuples to use as a filter; example[('CA',64.5),('H',7.8)]
+    :type filtering_rules: list
+    :param ph_min: minimum value for the filter based on PH value, defaults to None
+    :type ph_min: float, optional
+    :param ph_max: maximum value for the filter based on PH value, defaults to None
+    :type ph_max: float, optional
+    :param t_min: minimum value for the filter based on temperature value, defaults to None
+    :type t_min: float, optional
+    :param t_max: maximum value for the filter based on temperature value, defaults to None
+    :type t_max: float, optional
+    :param h_tolerance: tolerance value in ppm to filter H chemical shifts. It will allow the chemical shift value
+        given in the filtering_rules +/- tolerance, defaults to 0.1
+    :type h_tolerance: float, optional
+    :param c_tolerance: tolerance value in ppm to filter C chemical shifts, It will allow the chemical shift value
+        given in the filtering_rules +/- tolerance, defaults to 2.0
+    :type c_tolerance: float, optional
+    :param n_tolerance: tolerance value in ppm to filter N chemical shifts, It will allow the chemical shift value
+        given in the filtering_rules +/- tolerance, defaults to 2.0
+    :type n_tolerance: float, optional
+    :param standard_amino_acids: get data only form standard amino acids and nucleic acids when '*' is used for residue,
+        defaults to True
+    :type standard_amino_acids: bool, optional
     :return: chemical shift values as list
+    :rtype: list
     """
 
     cs_data = get_data_from_bmrb(residue=residue, ph_min=ph_min, ph_max=ph_max,
@@ -427,11 +547,11 @@ def get_filtered_data_from_bmrb(residue: str, atom: str, filtering_rules: list,
     def cs_filt(cs_dict2: dict, atm2: str, cs_val: float) -> dict:
         cs_width = 0.5
         if 'H' in atm2:
-            cs_width = 0.1
+            cs_width = h_tolerance
         if 'C' in atm2:
-            cs_width = 2.0
+            cs_width = c_tolerance
         if 'N' in atm2:
-            cs_width = 2.0
+            cs_width = n_tolerance
         out_cs_dict = {}
         for key2 in cs_dict2.keys():
             try:
@@ -452,27 +572,49 @@ def get_filtered_data_from_bmrb(residue: str, atom: str, filtering_rules: list,
     return x
 
 
-def get_statistics(residue: str = None, atom: str = None, list_of_atoms: list = None, filtered: bool = True,
-                   sd_limit: float = 10,
-                   ambiguity: Union[str, int] = '*',
-                   ph_min: float = None, ph_max: float = None, t_min: float = None, t_max: float = None,
-                   standard_amino_acids: bool = True, verbose: bool = False) -> dict:
+def get_statistics(residue: str,
+                   atom: str,
+                   list_of_atoms: Optional[Union[str, List[str]]] = None,
+                   filtered: Optional[bool] = True,
+                   sd_limit: Optional[float] = 10.0,
+                   ambiguity: Optional[Union[str, int]] = '*',
+                   ph_min: Optional[float] = None,
+                   ph_max: Optional[float] = None,
+                   t_min: Optional[float] = None,
+                   t_max: Optional[float] = None,
+                   standard_amino_acids: Optional[bool] = True,
+                   verbose: bool = False) -> dict:
     """
     Provides chemical shift statistics like Mean, Median, Standard deviation for a given residue/atom/list of atoms
 
-    :param residue: Single residue name or list of residue names  in IUPAC format
-    :param atom: Single atom name or list of atom names in IUPAC format
-    :param list_of_atoms: list of atoms; example ['ALA-CB','CYS-N','TYR-CB']
-    :param filtered: Filters values beyond (sd_limit)*(standard deviation) on both sides of the mean; default:True
-    :param sd_limit: scaling factor used to filter data based on standard deviation; default 10
-    :param ambiguity: ambiguity filter; default '*' => no filter
-    :param ph_min: PH filter (min);default None
-    :param ph_max: PH filter (max); default None
-    :param t_min: Temperature filter (min); default None
-    :param t_max: Temperature filter (max); default None
-    :param standard_amino_acids: get data only form standard amino acids and nucleic acids; default:True
-    :param verbose: display the statistics on screen; default False
+    :param residue: Residue name in IUPAC format; use '*' for any residue
+    :type residue: str
+    :param atom: Atom name in IUPAC format; Wild card supported; example HB*; use '*' for any atom
+    :type atom: str
+    :param list_of_atoms: list of atoms; example ['ALA-CB','CYS-N','TYR-CB'], defaults to None
+    :type list_of_atoms: list, optional
+    :param filtered: Filters values beyond (sd_limit)*(standard deviation) on both sides of the mean,
+        defaults to True
+    :type filtered: bool, optional
+    :param sd_limit: scaling factor used to filter data based on standard deviation, defaults to 10.0
+    :type sd_limit: float, optional
+    :param ambiguity: filter based on chemical shift ambiguity code, defaults to '*' means no filter
+    :type ambiguity: str, optional
+    :param ph_min: minimum value for the filter based on PH value, defaults to None
+    :type ph_min: float, optional
+    :param ph_max: maximum value for the filter based on PH value, defaults to None
+    :type ph_max: float, optional
+    :param t_min: minimum value for the filter based on temperature value, defaults to None
+    :type t_min: float, optional
+    :param t_max: maximum value for the filter based on temperature value, defaults to None
+    :type t_max: float, optional
+    :param standard_amino_acids: get data only form standard amino acids and nucleic acids when '*' is used for residue,
+        defaults to True
+    :type standard_amino_acids: bool, optional
+    :param verbose: display the statistics on screen; defaults  to False
+    :type verbose: bool, optional
     :return: chemical shift statistics as a dictionary
+    :rtype: dict
     """
 
     if residue is None and atom is None and list_of_atoms is None:
@@ -499,7 +641,7 @@ def get_statistics(residue: str = None, atom: str = None, list_of_atoms: list =
         cs_stat[atm] = {}
         res = atm.split("-")[0]
         at = atm.split("-")[1]
-        x = [i[cs_index] for i in data if i[res_index] == res and i[atm_index] == at]
+        x = [float(i[cs_index]) for i in data if i[res_index] == res and i[atm_index] == at]
         cs_stat[atm]['cs'] = x
         cs_stat[atm]['mean'] = round(float(numpy.mean(x)), 3)
         cs_stat[atm]['median'] = round(float(numpy.median(x)), 3)
@@ -512,17 +654,9 @@ def get_statistics(residue: str = None, atom: str = None, list_of_atoms: list =
             print('\t\t{}'.format(key))
             print('\t\tMean\t\t\t\t:{}'.format(cs_stat[key]['mean']))
             print('\t\tMedian\t\t\t\t:{}'.format(cs_stat[key]['median']))
-            print('\t\tStandard deviation\t:{}'.format(cs_stat[key]['std']))
+            print('\t\tStandard deviation\t\t:{}'.format(cs_stat[key]['std']))
             print('\t\tMinimum\t\t\t\t:{}'.format(cs_stat[key]['min']))
             print('\t\tMaximum\t\t\t\t:{}'.format(cs_stat[key]['max']))
             print('\t\tCount\t\t\t\t:{}'.format(cs_stat[key]['count']))
             print("\n")
     return cs_stat
-
-# if __name__=="__main__":
-#     # x=ChemicalShiftStatistics.get_data_from_bmrb(list_of_atoms='ALA-N')
-#     # #print (x[0])
-#     # y=ChemicalShiftStatistics._list_to_dict(x[0],x[1])
-#     #x=ChemicalShiftStatistics.get_2d_chemical_shifts(residue='ALA',atom1='CA',atom2='CB')
-#     #x=ChemicalShiftStatistics.get_filtered_data_from_bmrb(residue='THR',atom='N',filtering_rules=[('CB',69.51),('CA',60.79),('H',8.13)])
-#     ChemicalShiftStatistics.get_statistics(residue='GLY',atom='XX')
